"""
Yumako - Vanilla python utilities.
"""

__version__ = "0.1.6"

import importlib
from types import ModuleType
from typing import TYPE_CHECKING

__submodules = [
    "template",
    "time",
]
__submodule_map = {name: f"yumako.{name}" for name in __submodules}

if TYPE_CHECKING:
    from . import template  # type: ignore
    from . import time  # type: ignore


def __getattr__(name: str) -> ModuleType:
    if name in __submodule_map:
        submodule = importlib.import_module(__submodule_map[name])
        globals()[name] = submodule
        return submodule
    raise AttributeError(f"Module {__name__!r} has no attribute {name!r}")


__all__ = __submodules


def __dir__() -> list[str]:
    return __all__
